import re

from gurmukhiutils.unicode import unicode_normalize


def ascii(
    string: str,
) -> str:
    """
    Converts Gurmukhi to ASCII for Open Gurbani Akhar font.

    Note:
        Open Gurbani Akhar is the only font that can fully render the Shabad OS Database. Historically, every other ASCII font has been insufficiently capable.

    Args:
        string: The string to affect.

    Returns:
        A string whose Gurmukhi is converted to an ascii font format.

    Examples:
        >>> ascii("੧੨੩")
        '123'

        >>> ascii("ਗੁਰੂ")
        'gurU'
    """

    ASCII_TRANSLATION = {
        ord("ੳ"): "a",
        ord("ਅ"): "A",
        ord("ੲ"): "e",
        ord("ਸ"): "s",
        ord("ਹ"): "h",
        ord("ਕ"): "k",
        ord("ਖ"): "K",
        ord("ਗ"): "g",
        ord("ਘ"): "G",
        ord("ਙ"): "|",
        ord("ਚ"): "c",
        ord("ਛ"): "C",
        ord("ਜ"): "j",
        ord("ਝ"): "J",
        ord("ਞ"): "\\",
        ord("ਟ"): "t",
        ord("ਠ"): "T",
        ord("ਡ"): "f",
        ord("ਢ"): "F",
        ord("ਣ"): "x",
        ord("ਤ"): "q",
        ord("ਥ"): "Q",
        ord("ਦ"): "d",
        ord("ਧ"): "D",
        ord("ਨ"): "n",
        ord("ਪ"): "p",
        ord("ਫ"): "P",
        ord("ਬ"): "b",
        ord("ਭ"): "B",
        ord("ਮ"): "m",
        ord("ਯ"): "X",
        ord("ਰ"): "r",
        ord("ਲ"): "l",
        ord("ਵ"): "v",
        ord("ੜ"): "V",
        ord("ਸ਼"): "S",
        ord("ਜ਼"): "z",
        ord("ਖ਼"): "^",
        ord("ਫ਼"): "&",
        ord("ਗ਼"): "Z",
        ord("ਲ਼"): "L",
        ord("਼"): "æ",
        ord("ੑ"): "@",
        ord("ੵ"): "\u00b4",  # acute accent (´)
        ord("ਃ"): "Ú",  # capital u-acute letter
        ord("\u0a13"): "E",  # ਓ
        ord("\u0a06"): "Aw",  # ਆ
        ord("\u0a07"): "ei",  # ਇ
        ord("\u0a08"): "eI",  # ਈ
        ord("\u0a09"): "au",  # ਉ
        ord("\u0a0a"): "aU",  # ਊ
        ord("\u0a0f"): "ey",  # ਏ
        ord("\u0a10"): "AY",  # ਐ
        ord("\u0a14"): "AO",  # ਔ
        ord("ਾ"): "w",
        ord("ਿ"): "i",
        ord("ੀ"): "I",
        ord("ੁ"): "u",
        ord("ੂ"): "U",
        ord("ੇ"): "y",
        ord("ੈ"): "Y",
        ord("ੋ"): "o",
        ord("ੌ"): "O",
        ord("ੰ"): "M",
        ord("ਂ"): "N",
        ord("ੱ"): "`",
        ord("।"): "[",
        ord("॥"): "]",
        ord("੦"): "0",
        ord("੧"): "1",
        ord("੨"): "2",
        ord("੩"): "3",
        ord("੪"): "4",
        ord("੫"): "5",
        ord("੬"): "6",
        ord("੭"): "7",
        ord("੮"): "8",
        ord("੯"): "9",
        ord("ੴ"): "<>",
        ord("☬"): "Ç",
    }

    ASCII_REPLACEMENTS = {
        "੍ਯ": "Î",  # half-yayya
        "꠳ਯ": "Î",  # sant lipi variation
        "꠴ਯ": "ï",  # open-top yayya
        "꠵ਯ": "î",  # open-top half-yayya
        "੍ਰ": "R",
        "੍ਵ": "Í",  # capital i-acute letter
        "੍ਹ": "H",
        "੍ਚ": "ç",  # c-cedilla letter
        "੍ਟ": "†",  # dagger symbol
        "੍ਤ": "œ",
        "੍ਨ": "\u02dc",  # small tilde (˜)
    }

    string = unicode_normalize(string)

    for key, value in ASCII_REPLACEMENTS.items():
        string = string.replace(key, value)

    string = string.translate(ASCII_TRANSLATION)

    # Re-arrange sihari
    ASCII_BASE_LETTERS = r"aAeshkKgG\|cCjJ\\tTfFxqQdDnpPbBmXrlvVSz^&ZLÎïî"
    ASCII_MODIFIERS = "æ@\u00b4ÚwIuUyYoO`MNRÍHç†œ\u02dcü\u00a8®µ\u02c6W~¤Ï"
    _regex = rf"([{ASCII_BASE_LETTERS}][{ASCII_MODIFIERS}]*)i([{ASCII_MODIFIERS}]*)"
    string = re.sub(_regex, r"i\1\2", string)

    # Fix below-base-letter + u vowel positioning
    ASCII_BELOW_BASE_LETTERS = "RÍHç†œ\u02dc\u00b4@"
    BELOW_VOWEL_MAPPINGS = {
        "u": "ü",
        "U": "¨",
    }
    for key, value in BELOW_VOWEL_MAPPINGS.items():
        _regex = rf"([{ASCII_BELOW_BASE_LETTERS}][{ASCII_MODIFIERS}]*){key}([{ASCII_MODIFIERS}]*)"
        string = re.sub(_regex, rf"\1{value}\2", string)

    # Fix center-stroke + tippi positioning
    CENTER_STROKE_LETTERS = "nT"
    _regex = rf"([{CENTER_STROKE_LETTERS}][{ASCII_MODIFIERS}]*)M([{ASCII_MODIFIERS}]*)"
    string = re.sub(_regex, r"\1µ\2", string)

    # Fix positioning of bindi when it is the only above-base-form
    ASCII_NON_ABOVE_MODIFIERS = "æ@\u00b4ÚwuURÍHç†œ\u02dcü\u00a8®Ï"
    _regex = rf"([{ASCII_BASE_LETTERS}][{ASCII_NON_ABOVE_MODIFIERS}]*)N([{ASCII_NON_ABOVE_MODIFIERS}]*)"
    string = re.sub(_regex, r"\1ˆ\2", string)

    # Make rendering changes for combos
    ASCII_COMBO_REPLACEMENTS = {
        "I\u0a01": "ˆØI",  # bindi + bihari ligature
        "IM": "µØI",  # tippi + bihari ligature
        "Iµ": "µØI",  # tippi + bihari ligature
        "kR": "k®",  # kakka + pair-rara ligature
        "H¨": "§",
        "wN": "W",  # addhak positioning
        "wˆ": "W",  # addhak positioning
        "nUµ": "ƒ",
    }
    for key, value in ASCII_COMBO_REPLACEMENTS.items():
        string = string.replace(key, value)

    return string



# pause chars / ਵਿਸ਼ਰਾਮ symbols
VISHRAM_LIGHT = "."
VISHRAM_MEDIUM = ","
VISHRAM_HEAVY = ";"
VISHRAMS = [VISHRAM_LIGHT, VISHRAM_MEDIUM, VISHRAM_HEAVY]

BASE_LETTERS = "ਸਹਕਖਗਘਙਚਛਜਝਞਟਠਡਢਣਤਥਦਧਨਪਫਬਭਮਯਰਲਵੜਸ਼ਖ਼ਗ਼ਜ਼ਫ਼ਲ਼"
VOWEL_LETTERS = (
    # ਅ ਆ ਏ ਐ ਇ ਈ ਓ ਔ ਉ ਊ
    "ਅ\u0a06\u0a0f\u0a10\u0a07\u0a08\u0a13\u0a14\u0a09\u0a0a"
)

ORDERED_VOWELS = [
    "ਿ",
    "ੇ",
    "ੈ",
    "ੋ",
    "ੌ",
    "ੁ",
    "ੂ",
    "ਾ",
    "ੀ",
]

VIRAMA = "੍"
BELOW_LETTERS = "ਹਰਵਟਤਨਚ"
YAKASH = "ੵ"

VOWEL_DIACRITICS = "".join(ORDERED_VOWELS)



from typing import Literal

from gurmukhiutils.converters.guru_latn import guru_latn
from gurmukhiutils.converters.guru_latn_pa import guru_latn_pa
from gurmukhiutils.unicode import unicode_normalize

TRANSLATORS = Literal["guru_latn", "guru_latn_pa"]


def convert(
    string: str,
    scriptConverter: Literal[TRANSLATORS] = "guru_latn_pa",
) -> str:
    """
    Converts text from a script to another.

    Note:
        Some script converters are lossless and others are lossy. Transliteration attempts to be compliant with reversible mappings (i.e. to a target script and then back to unicode gurmukhi with zero data loss). Transcription attempts to be representative of the spoken word (biased by today's languages). Script converters are named with two script tags (based on ISO 15924) for transliteration, and an additional language tag (based on ISO 639-1) for transcription. Additional information may be added at the end to indicate school of thought or other methodology info.

    Args:
        string: The string to affect.

        scriptConverter: The method of converting one script to another . Defaults to "guru_latn_pa".

    Returns:
        A string where a script is converted to another script.

    Examples:
        >>> convert("੧੨੩")
        '123'

        >>> convert("ਗੁਰੂ")
        'gurū'
    """

    # Convert Unicode to Sant Lipi format
    string = string.replace("੍ਯ", "꠳ਯ")

    string = unicode_normalize(string)

    if scriptConverter == "guru_latn":
        string = guru_latn(string)

    if scriptConverter == "guru_latn_pa":
        string = guru_latn_pa(string)

    return string



import re

from gurmukhiutils.constants import (
    BASE_LETTERS,
    BELOW_LETTERS,
    VIRAMA,
    VOWEL_LETTERS,
    YAKASH,
)
from gurmukhiutils.converters.guru_latn import guru_latn
from gurmukhiutils.unicode import unicode_normalize

TRANSLIT_ALTERATIONS = {
    ord("ਖ਼"): "ḳh",
}

ROMAN_LIT2SCRIPT_TRANSLATIONS = {
    ord("ƴ"): "y",
    ord("ʸ"): "y",
    ord("ʰ"): "h",
    ord("ʳ"): "r",
    ord("ᵛ"): "v",
    ord("ⁿ"): "n",
    ord("ᶜ"): "c",
    ord("⸛"): "ñ",
    ord("⸞"): "ñ",
    ord("̧"): None,
}

ROMAN_LIT2SCRIPT_REPLACEMENTS = {
    "y̶": "y",
    "ƴ̶": "y",
    "ᵗ̣": "ṭ",
    "ᵗ": "t",
    "va": "wa",
    "vu": "wu",
    "vū": "wū",
    "vo": "wo",
    "vō": "wō",
}


def guru_latn_pa(
    string: str,
) -> str:
    """
    Converts text from gurmukhi script to roman in a lossless fashion using modern punjabi rules.

    Args:
        string: The string to affect.

    Returns:
        A string where the gurmukhi script is converted to roman script.

    Examples:
        >>> guru_latn_pa("੧੨੩")
        '123'

        >>> guru_latn_pa("ਗੁਰੂ")
        'gurū'
    """

    # confirm normalized gurmukhi
    string = unicode_normalize(string)

    # remove grammatical vowels before converting from gurmukhi

    # remove ਿ and ੁ from end of words
    # ignore single letter words
    # type ignore comment is to stop mypy complaining about List[Any], see https://github.com/python/typeshed/issues/263
    if len(re.findall(rf"[{VOWEL_LETTERS}{BASE_LETTERS}]", string)) > 1:  # type: ignore
        string = re.sub(
            r"(ਿ?)(ੇ?ੈ?ੋ?ੌ?)(ੁ?)(ੂ?ਾ?ੀ?)(ਁ?ੱ?ਂ?ੰ?ਃ?)(‧|\s|$)", r"\2\4\5\6", string
        )

    # shorten ੋੁ from start of words
    # note: cannot use []{2} for whatever reason
    HORA_ONKAR = "\u0a4b\u0a41"
    DULAVAN_ONKAR = "\u0a48\u0a41"
    string = re.sub(
        rf"(^|\s|‧)([{BASE_LETTERS}])({VIRAMA}[{BELOW_LETTERS}]|{YAKASH})?[{HORA_ONKAR}][{HORA_ONKAR}]",
        r"\1\2\3ੋ",
        string,
    )
    string = re.sub(
        rf"(^|\s|‧)([{BASE_LETTERS}])({VIRAMA}[{BELOW_LETTERS}]|{YAKASH})?[{DULAVAN_ONKAR}][{DULAVAN_ONKAR}]",
        r"\1\2\3ੈ",
        string,
    )

    # handle ਹ rules

    # if vowel-less haha is preceded by sihari or onkar (ਿ or ੁ), represent lavan and hora respectively (ੇ and ੋ)
    # if vowel-less base letter is followed by a haha with sihari or onkar, yield dulavan and kanora respectively (ੈ and ੌ)
    # TODO find more tests/cases (this is a simple check and will not catch potentially more complex scenarios)

    # string = re.sub(
    #     r"([꠳꠴꠵]?)ਯਹੁ",
    #     r"\1ਯੌਹ‧",
    #     string,
    # )

    # string = re.sub(
    #     rf"([ਯ{BASE_LETTERS}])(ਿ)(ਂ?ੰ?)(ਹ)(?![{VIRAMA}{YAKASH}{VOWEL_DIACRITICS}])",
    #     r"\1ੇ\3\4‧",
    #     string,
    # )
    # string = re.sub(
    #     rf"(ਇ)(ਂ?ੰ?)(ਹ)(?![{VIRAMA}{YAKASH}{VOWEL_DIACRITICS}])",
    #     r"ਏ\2\3‧",
    #     string,
    # )

    # string = re.sub(
    #     rf"([ਯ{BASE_LETTERS}])(ੁ)(ਂ?ੰ?)(ਹ)(?![{VIRAMA}{YAKASH}{VOWEL_DIACRITICS}])",
    #     r"\1ੋ\3\4‧",
    #     string,
    # )
    # string = re.sub(
    #     rf"(ਉ)(ਂ?ੰ?)(ਹ)(?![{VIRAMA}{YAKASH}{VOWEL_DIACRITICS}])",
    #     r"ਓ\2\3‧",
    #     string,
    # )

    # string = re.sub(
    #     rf"([ਯ{BASE_LETTERS}])(ਹਿ)",
    #     r"\1ੈਹ‧",
    #     string,
    # )

    # string = re.sub(
    #     rf"(ਯ|[{BASE_LETTERS}])(ਹੁ)",
    #     r"\1ੌਹ‧",
    #     string,
    # )

    # do alternate translit before function translit
    string = string.translate(TRANSLIT_ALTERATIONS)
    string = guru_latn(string)

    # separate parts and treat individually
    strings = string.split("‧")

    enumerate = ""

    for string in strings:
        string = string.translate(ROMAN_LIT2SCRIPT_TRANSLATIONS)

        # add mukta after ending half-y
        string = re.sub(r"a([yƴ]̶)(\s|$)", r"\1a\2", string)

        # nullify mukta + half-y
        string = re.sub(r"a([yƴ]̶)", r"\1", string)

        for key, value in ROMAN_LIT2SCRIPT_REPLACEMENTS.items():
            string = string.replace(key, value)

        # gemminate/double char following adhak
        string = re.sub(r"˘([a-zġṅñṇḍṭṛḷḳ])", r"\1\1", string)

        enumerate += string

    return enumerate



import re

from gurmukhiutils.constants import BASE_LETTERS, BELOW_LETTERS, VIRAMA, YAKASH
from gurmukhiutils.unicode import unicode_normalize

ROMAN_REPLACEMENTS = {
    "ਕ਼": "q",
    "੍ਯ": "y̶",  # half-yayya uses strikethrough U+0336
    "꠳ਯ": "y̶",
    "꠴ਯ": "ƴ",  # open-top yayya uses latin y with hook U+01B4
    "꠵ਯ": "ƴ̶",  # open-top half-yayya is a combination of U+01B4 and U+0336
    "ੵ": "ʸ",
    "੍ਹ": "ʰ",
    "੍ਰ": "ʳ",
    "੍ਵ": "ᵛ",
    "੍ਟ": "ᵗ̣",
    "੍ਤ": "ᵗ",
    "੍ਨ": "ⁿ",
    "੍ਚ": "ᶜ",
}

ROMAN_TRANSLATIONS = {
    ord("ਾ"): "ā",
    ord("ੇ"): "e",
    ord("ੈ"): "ē",
    ord("ਿ"): "i",
    ord("ੀ"): "ī",
    ord("ੋ"): "o",
    ord("ੌ"): "ō",
    ord("ੁ"): "u",
    ord("ੂ"): "ū",
    ord("ਅ"): "a",
    ord("\u0a06"): "ā",  # ਆ
    ord("\u0a0f"): "e",  # ਏ
    ord("\u0a10"): "ē",  # ਐ
    ord("\u0a07"): "i",  # ਇ
    ord("\u0a08"): "ī",  # ਈ
    ord("\u0a13"): "o",  # ਓ
    ord("\u0a14"): "ō",  # ਔ
    ord("\u0a09"): "u",  # ਉ
    ord("\u0a0a"): "ū",  # ਊ
    ord("ਸ"): "s",
    ord("ਹ"): "h",
    ord("ਕ"): "k",
    ord("ਖ"): "kh",
    ord("ਗ"): "g",
    ord("ਘ"): "gh",
    ord("ਙ"): "ṅ",
    ord("ਚ"): "c",
    ord("ਛ"): "ch",
    ord("ਜ"): "j",
    ord("ਝ"): "jh",
    ord("ਞ"): "ñ",
    ord("ਟ"): "ṭ",
    ord("ਠ"): "ṭh",
    ord("ਡ"): "ḍ",
    ord("ਢ"): "ḍh",
    ord("ਣ"): "ṇ",
    ord("ਤ"): "t",
    ord("ਥ"): "th",
    ord("ਦ"): "d",
    ord("ਧ"): "dh",
    ord("ਨ"): "n",
    ord("ਪ"): "p",
    ord("ਫ"): "ph",
    ord("ਬ"): "b",
    ord("ਭ"): "bh",
    ord("ਮ"): "m",
    ord("ਯ"): "y",
    ord("ਰ"): "r",
    ord("ਲ"): "l",
    ord("ਵ"): "v",
    ord("ੜ"): "ṛ",
    ord("ਸ਼"): "sh",
    ord("ਖ਼"): "x",
    ord("ਗ਼"): "ġ",
    ord("ਜ਼"): "z",
    ord("ਫ਼"): "f",
    ord("ਲ਼"): "ḷ",
    ord("਼"): "°",
    ord("੦"): "0",
    ord("੧"): "1",
    ord("੨"): "2",
    ord("੩"): "3",
    ord("੪"): "4",
    ord("੫"): "5",
    ord("੬"): "6",
    ord("੭"): "7",
    ord("੮"): "8",
    ord("੯"): "9",
    ord("ੑ"): "̧",  # U+0327 Combining Cedilla
    ord("ੱ"): "˘",
    ord("ੰ"): "⸛",
    ord("ਂ"): "⸞",
    ord("ਃ"): "ẖ",
    ord("।"): "|",
    ord("॥"): "‖",  # U+2016 Double Vertical Line
}


def guru_latn(
    string: str,
) -> str:
    """
    Converts text from gurmukhi script to roman in a lossless fashion.

    Args:
        string: The string to affect.

    Returns:
        A string where the gurmukhi script is converted to roman script.

    Examples:
        >>> guru_latneration("੧੨੩")
        '123'

        >>> guru_latneration("ਗੁਰੂ")
        'gurū'
    """

    # confirm normalized gurmukhi
    string = unicode_normalize(string)

    # Ik Oankar
    string = string.replace("ੴ", "ਇਕ ਓਅੰਕਾਰ")

    # Add inherent vowel / Mukta (ਮੁਕਤਾ = ਅ)

    # Between words
    NON_VOWEL_MODIFIERS = "਼ੑੵ਼"
    PRE_BASE_LIGATURE = "꠳꠴꠵"
    POST_LETTERS = "ਆਏਐਇਈਓਔਉਊ"
    PRE_POST_MODIFIERS = "ੱਂੰ"

    REGEX_PATTERN = rf"([{BASE_LETTERS}][{NON_VOWEL_MODIFIERS}]?)(?=[{PRE_BASE_LIGATURE}{BASE_LETTERS}{POST_LETTERS}{PRE_POST_MODIFIERS}])"

    string = re.sub(REGEX_PATTERN, r"\1ਅ", string)

    # Single letter
    SINGLE_CHAR_PATTERN = rf"(^|\s|$)([{BASE_LETTERS}][{NON_VOWEL_MODIFIERS}]?)([{VIRAMA}][{BELOW_LETTERS}]|{YAKASH})?(^|\s|$)"

    string = re.sub(SINGLE_CHAR_PATTERN, r"\1\2\3ਅ\4", string)

    for key, value in ROMAN_REPLACEMENTS.items():
        string = string.replace(key, value)

    string = string.translate(ROMAN_TRANSLATIONS)

    return string



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['gurmukhiutils', 'gurmukhiutils.converters']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'gurmukhiutils',
    'version': '0.3.0',
    'description': 'Python utilities library for converting, analyzing, and testing Gurmukhi strings',
    'long_description': '# Gurmukhi Utils\n\nPython utilities library for converting, analyzing, and testing Gurmukhi strings. This project is an original work inspired by the JavaScript library [gurmukhi-utils](https://github.com/shabados/gurmukhi-utils).\n\n## WIP\n\nThis library is a work in progress! Note that the API can change unexpectedly when upgrading. It will not be using [SemVer](https://semver.org/) until version 1.0.0. Please do not use for critical projects yet.\n\n## Installation\n\n```shell\npip3 install gurmukhiutils\n```\n\n```shell\npoetry add gurmukhiutils\n```\n\n## Usage\n\nThis is a cursory overview of the functions available. To learn more, see any function\'s docstring in the source code.\n\n**Module `gurmukhiutils.unicode`**\n\n- `unicode` - Converts any ascii gurmukhi characters and sanitizes to unicode gurmukhi. Supports markup language of [Sant Lipi](https://github.com/shabados/SantLipi).\n- `unicode_normalize` - Normalizes Gurmukhi according to Unicode Standards.\n- `sort_diacritics` - Orders the gurmukhi diacritics in a string according to Unicode standards.\n- `sanitize_unicode` - Use single char representations of constructed characters.\n\n**Module `gurmukhiutils.convert`**\n\nConverts text from a script to another. Currently only supports lossless Gurmukhi to Roman transliteration. Gurmukhi to Roman transcription is a WIP.\n\n**Module `gurmukhiutils.remove`**\n\n- `remove` - Removes substrings from string.\n- `remove_regex` - Removes regex patterns from string.\n- `remove_line_endings` - Attempts to remove line endings as best as possible.\n- `remove_vishrams` - Removes all vishram characters.\n\n**`gurmukhiutils.ascii`** - Converts Gurmukhi to ASCII for Open Gurbani Akhar font.\n\n**Example**\n\n```python\n>>> from gurmukhiutils.unicode import unicode\n>>> unicode("gurU")\n\'ਗੁਰੂ\'\n\n>>> from gurmukhiutils.convert import convert\n>>> convert("ਗੁਰੂ")\n\'gurū\'\n```\n\n## Contribute\n\nIf you want to help, please get started with the [CONTRIBUTING.md](./CONTRIBUTING.md) doc.\n\n## Community\n\nThe easiest way to communicate is via [GitHub issues](https://github.com/shabados/viewer/issues). Please search for similar issues regarding your concerns before opening a new issue.\n\nGet organization updates for Shabad OS by following us on [Instagram](https://www.instagram.com/shabad_os/) and [Twitter](https://twitter.com/shabad_os/). We also invite you to join us on our public chat server hosted on [Slack](https://chat.shabados.com/).\n\nOur intention is to signal a safe open-source community. Please help us foster an atmosphere of kindness, cooperation, and understanding. By participating, you agree to abide by the [Contributor Covenant](https://www.contributor-covenant.org/version/2/0/code_of_conduct/).\n\nIf you have a concern that doesn\'t warrant opening a GitHub issue, please reach out to us:\n\nBhajneet S.K., Author, Maintainer, Project Lead: [@bhajneet](https://github.com/bhajneet/)\n',
    'author': 'Bhajneet S.K.',
    'author_email': 'bhajneet@gmail.com',
    'maintainer': 'Bhajneet S.K.',
    'maintainer_email': 'bhajneet@gmail.com',
    'url': 'https://github.com/shabados/gurmukhiutils',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
